xpaw
====

.. image:: https://travis-ci.org/jadbin/xpaw.svg?branch=master
    :target: https://travis-ci.org/jadbin/xpaw

.. image:: https://coveralls.io/repos/jadbin/xpaw/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/jadbin/xpaw?branch=master

.. image:: https://img.shields.io/badge/license-Apache 2-blue.svg
    :target: https://github.com/jadbin/xpaw/blob/master/LICENSE


Overview
--------

xpaw is a web scraping framework, used to crawl web pages and extract structured data from them.


Requirements
------------

- Python >= 3.5
- `aiohttp`_
- `pyyaml`_
- `lxml`_

.. _aiohttp: https://pypi.python.org/pypi/aiohttp
.. _pyyaml: https://pypi.python.org/pypi/pyyaml
.. _lxml: https://pypi.python.org/pypi/lxml


Documentation
-------------

Full documentation and usage examples for xpaw can be found on `readthedocs`_.

.. _readthedocs: http://xpaw.readthedocs.org/en/latest/
